@@ -67,7 +67,7 @@ harness <- function(which = NULL,
     if (is.null(which)) {
         fnIndices <- seq_along(fns)
     } else {
-        fnIndices <- match(which, names(fns))
+        fnIndices <- na.omit(match(which, names(fns)))
     }
     fnList <- lapply(names(fns)[fnIndices], function(x) call(x))
 
@@ -293,3 +293,6 @@ d <- harness(f = I.2d, fv = I.2d_v,
              lowerLimit = rep(-1, 2), upperLimit = rep(1, 2), times = 100)
 knitr::kable(d, digits = 3)
 
+## ------------------------------------------------------------------------
+sessionInfo()
+
